<p align="center">
 <img src="https://github.com/DEViantUA/Akasha-Terminal/blob/main/BannerAkasha.png?raw=true" alt="Баннер"/>
</p>


# Akasha-Terminal
Python module for providing game information from different sources.
